tlslite.errors.TLSAlert

Package tlslite :: Module errors :: Class TLSAlert |
[show private | hide private]
[frames | no frames]

## Class TLSAlert

    Exception --+
                |
         TLSError --+
                    |
                   TLSAlert

Known Subclasses:
  `TLSLocalAlert`, `TLSRemoteAlert`

A TLS alert has been signalled.

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net